/*
 *  Quick Test: CLI for stress testing in competitive programming
 *  Copyright (C) 2021-present / Luis Miguel Báez
 *  License: MIT (See the LICENSE file in the repository root directory)
 */

pub mod cmd_check;
pub mod cmd_cmp;
pub mod cmd_example;
pub mod cmd_run;
pub mod cmd_setup;
pub mod cmd_stress;
